pystagram.graph_api.components.containers package — pystagram 0.1 documentation

# pystagram.graph_api.components.containers package

## Submodules

## pystagram.graph_api.components.containers.base_container module

class pystagram.graph_api.components.containers.base_container.BaseContainer

  Bases: `ABC`

  property fields

## pystagram.graph_api.components.containers.carousel_container module

class pystagram.graph_api.components.containers.carousel_container.CarouselContainer(children: List[BaseContainer], caption: str | None = None)

  Bases: `BaseContainer`

## pystagram.graph_api.components.containers.image_container module

class pystagram.graph_api.components.containers.image_container.ImageContainer(image_url: str, is_carousel_item: bool | None = False, is_story: bool | None = False, caption: str | None = None, collaborators: List[str] | None = None, location_id: str | None = None, user_tags: List[UserTag] | None = None, product_tags: str | None = None)

  Bases: `BaseContainer`

## pystagram.graph_api.components.containers.reel_container module

class pystagram.graph_api.components.containers.reel_container.ReelContainer(video_url: str, share_to_feed: bool | None = True, caption: str | None = None, collaborators: List[str] | None = None, cover_url: str | None = None, audio_name: str | None = None, user_tags: List[UserTag] | None = None, location_id: str | None = None, thumb_offset: int | None = 0)

  Bases: `BaseContainer`

## pystagram.graph_api.components.containers.video_container module

class pystagram.graph_api.components.containers.video_container.VideoContainer(video_url: str, is_carousel_item: bool | None = False, caption: str | None = None, collaborators: List[str] | None = None, location_id: str | None = None, user_tags: List[UserTag] | None = None, product_tags: str | None = None)

  Bases: `BaseContainer`

## Module contents